@@ -1,4 +1,6 @@
 # -*- coding: utf-8 -*-
+# Copyright (C) 2020 Red Hat, Inc.
+#
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
 # You may obtain a copy of the License at
@@ -24,9 +26,9 @@ extensions = [
 ]
 
 # openstackdocstheme options
-repository_name = 'openstack/oslo.concurrency'
-bug_project = 'oslo.concurrency'
-bug_tag = ''
+openstackdocs_repo_name = 'openstack/oslo.concurrency'
+openstackdocs_bug_project = 'oslo.concurrency'
+openstackdocs_bug_tag = ''
 
 # The master toctree document.
 master_doc = 'index'
@@ -42,14 +44,12 @@ add_function_parentheses = True
 add_module_names = True
 
 # The name of the Pygments (syntax highlighting) style to use.
-pygments_style = 'sphinx'
-
+pygments_style = 'native'
 
 # -- Options for HTML output -------------------------------------------------
 
 html_theme = 'openstackdocs'
 
-
 # -- sphinxcontrib.apidoc configuration --------------------------------------
 
 apidoc_module_dir = '../../'
